abclinuxu.cz AbcLinuxu.cz itbiz.cz ITBiz.cz HDmag.cz HDmag.cz abcprace.cz AbcPráce.cz
AbcLinuxu hledá autory!
Inzerujte na AbcPráce.cz od 950 Kč
Rozšířené hledání
×
    včera 23:22 | Bezpečnostní upozornění

    Výzkumníci ukazují, jak mohou otevřené tunely a IPv6 Extension Headers synchronizovat pakety do krátkých provozních špiček. V kontrolovaném experimentu naměřili přes 180násobnou koncentraci paketového toku vůči průměrné rychlosti odesílání — nikoli 180násobné zvětšení objemu dat. Článek obsahuje metodiku, limity měření i mitigace pro GRE, IPIP a další tunely.

    vencour | Komentářů: 1
    včera 12:44 | Pozvánky

    Po velkém úspěchu prvního MobileLinux Hackdaye se vracíme do Českých Budějovic s druhým ročníkem. V pátek 30. října 2026 od 10:00 se v prostorách Jihočeské univerzity uskuteční Embedded & MobileLinux Hackday #2. Těšit se můžete na témata jako Immutable Linux na telefonech (BengalOS), U-Boot a upstream vývoj, AI optimalizace pro embedded systémy nebo otevřený hardware. Nebude chybět praktické hackování, sdílení zkušeností a možnost … více »

    lkocman | Komentářů: 2
    včera 00:44 | Bezpečnostní upozornění

    Dne 21. října 2026 vydal projekt Node.js bezpečnostní aktualizace opravující deset zranitelností, včetně jedné umožňující potenciální vzdálené spuštění kódu (RCE). Nejzajímavější je CVE-2026-111497, chyba dekodéru Brotli, kterou objevili výzkumníci využívající OpenAI Codex Security. Chyba je v nativním dekodéru Brotli, nikoli v samotném JavaScriptu. Speciálně vytvořený komprimovaný vstup způsobí, že dekodér zamění

    … více »
    vencour | Komentářů: 13
    23.10. 17:44 | IT novinky

    Francouzský výrobce kabelů Nexans upozornil na napjaté dodávky elektrických kabelů. Výstavba nové výrobní linky pro některé typy kabelů může trvat přibližně tři roky. Datacentra potřebují rozsáhlé nízkonapěťové a středněnapěťové rozvody. Poptávka roste současně s modernizací elektrických sítí. Někteří odběratelé proto uzavírají výrazně delší dodavatelské smlouvy [Reuters].

    vencour | Komentářů: 15
    23.10. 14:44 | Zajímavý projekt

    Představena byla (𝕏) virtuální platforma FLYBENCH FPV, která nováčky provede zapojením a konstrukcí dronů.

    Ladislav Hagara | Komentářů: 6
    23.10. 04:11 | Nová verze

    Google Chrome 156 byl prohlášen za stabilní. Přehled novinek v poznámkách k vydání. Opraveno bylo 353 bezpečnostních chyb. Vylepšeny byly také nástroje pro vývojáře.

    Ladislav Hagara | Komentářů: 0
    22.10. 20:22 | IT novinky

    Indická společnost eMudhra po bezpečnostním incidentu, tj. kompromitaci soukromých klíčů osmi mezilehlých certifikátů své certifikační autority, opouští globální byznys s SSL/TLS certifikáty.

    Ladislav Hagara | Komentářů: 4
    22.10. 15:44 | Bezpečnostní upozornění

    Dle Phoronixu zveřejnila společnost Trend Micro prostřednictvím programu Zero Day Initiative (ZDI) několik hlášení bezpečnostních zranitelností přímo na veřejném mailing listu LKML, přestože některé chyby dosud nemají opravu začleněnou do hlavní větve jádra. Mezi hlášenými problémy jsou dvě zranitelnosti s hodnocením CVSS 9.0, týkající se SMB Direct a KSMBD, které mohou umožnit vzdálené spuštění kódu. Další hlášení se týkají … více »

    vencour | Komentářů: 0
    22.10. 15:33 | Nová verze

    Správce hesel KeePassXC byl vydán ve verzi 2.8.0. Přechází na Qt 6, podporuje vkládání hesel s Waylandem, rychlé odemykání pomocí Polkitu nebo možnost nastavení klávesových zkratek (seznam změn).

    ʚĭɞ 🍉 | Komentářů: 0
    22.10. 15:22 | Nová verze

    Databáze DuckDB (Wikipedie) byla vydána ve verzi 2.0.0 LTS. S kódovým názvem Cinnamon Teal (čírka skořicová). S vyladěným protokolem Quack.

    Ladislav Hagara | Komentářů: 0
    Které desktopové prostředí na Linuxu používáte?
     (9%)
     (7%)
     (4%)
     (20%)
     (30%)
     (9%)
     (5%)
     (2%)
     (14%)
     (20%)
    Celkem 2906 hlasů
     Komentářů: 33, poslední 20.10. 23:44
    Rozcestník

    Dotaz: Nejdou sestavit Catalysty pro Squeeze

    Jiří Svoboda avatar 21.3.2012 07:49 Jiří Svoboda | skóre: 37 | blog: cat /dev/mind | Prostějov
    Nejdou sestavit Catalysty pro Squeeze
    Přečteno: 585×
    Mám tu stroj s APU AMD E-350, nainstaloval jsem čistý Debian stable (Squeeze) a teď se marně pokouším sestavit balíčky fglrx-*. Postupuji podle návodu: http://wiki.cchtml.com/index.php/Debian.

    Pokud to udělám přesně podle návodu, skončím takto:
    jirkas@klapacius:~/build/catalyst12.2$ fakeroot sh amd-driver-installer-12-2-x86.x86_64.run --buildpkg Debian/stable
    Created directory fglrx-install.SgrU0G
    Verifying archive integrity... All good.
    Uncompressing AMD Catalyst(TM) Proprietary Driver-8.95....................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................
    =====================================================================
     AMD Catalyst(TM) Proprietary Driver Installer/Packager 
    =====================================================================
    Generating package: Debian/stable
    cp: cannot stat `/home/jirkas/build/catalyst12.2/fglrx-install.SgrU0G/x710/*': No such file or directory
    Package build failed!
    Package build utility output:
    dpkg-buildpackage: warning: using a gain-root-command while being root
    dpkg-buildpackage: export CFLAGS from dpkg-buildflags (origin: vendor): -g -O2
    dpkg-buildpackage: export CPPFLAGS from dpkg-buildflags (origin: vendor): 
    dpkg-buildpackage: export CXXFLAGS from dpkg-buildflags (origin: vendor): -g -O2
    dpkg-buildpackage: export FFLAGS from dpkg-buildflags (origin: vendor): -g -O2
    dpkg-buildpackage: export LDFLAGS from dpkg-buildflags (origin: vendor): 
    dpkg-buildpackage: source package fglrx-installer
    dpkg-buildpackage: source version 8.95-1
    dpkg-buildpackage: source changed by AMD: Advanced Micro Devices. -http://ati.amd.com/support/driver.html-
     dpkg-source --before-build fglrx.0Udz1T
    dpkg-buildpackage: host architecture i386
     debian/rules build
    dh_testdir
    # move licenses away from binary dir
    if [ ! -d usr/share/doc/fglrx ]; then \
    	  mkdir -p usr/share/doc/fglrx; \
    	  mv usr/X11R6/bin/LICENSE.* usr/share/doc/fglrx; \
    	fi
    # set executable on user apps
    find usr/X11R6/bin -type f | xargs chmod a+x
    # remove exec bit from files that don't deserve it
    find usr/X11R6/include \
    	     usr/X11R6/lib \
    	     usr/X11R6/lib64 \
    	     usr/share usr/src     -type f | xargs chmod -x
    find: `usr/X11R6/include': No such file or directory
    find: `usr/X11R6/lib64': No such file or directory
    find lib -not -name "*.sh" -type f | xargs chmod -x
    find lib      -name "*.sh" -type f | xargs chmod +x
    # set proper permissions on /etc files
    if [ -d etc/ati ]; then			\
    		chmod 755 etc/ati ;			\
    		chmod 644 etc/ati/* ;		\
    		chmod a+x etc/ati/*.sh ;	\
    	fi
    if [ -f debian/fglrx.default ]; then \
    	  mv -v debian/fglrx.default debian/fglrx; \
    	fi
    `debian/fglrx.default' -> `debian/fglrx'
     fakeroot debian/rules binary
    fakeroot: FAKEROOTKEY set to 1976793274
    fakeroot: nested operation not yet supported
    dpkg-buildpackage: error: fakeroot debian/rules binary gave error exit status 1
    Removing temporary directory: fglrx-install.SgrU0G
    jirkas@klapacius:~/build/catalyst12.2$ 
    
    Zdá se, že interně někde spouští znovu fakeroot a to mu vadí. Podle jedné vygooglené diskuze by se prý fakeroot používat neměl. Bez něj to ale pro změnu dopadne takto:
    jirkas@klapacius:~/build/catalyst12.2$ ./amd-driver-installer-12-2-x86.x86_64.run --buildpkg Debian/stable
    Created directory fglrx-install.ABmXYE
    Verifying archive integrity... All good.
    Uncompressing AMD Catalyst(TM) Proprietary Driver-8.95....................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................................
    =====================================================================
     AMD Catalyst(TM) Proprietary Driver Installer/Packager 
    =====================================================================
    Generating package: Debian/stable
    cp: cannot stat `/home/jirkas/build/catalyst12.2/fglrx-install.ABmXYE/x710/*': No such file or directory
    Package build failed!
    Package build utility output:
    dpkg-buildpackage: export CFLAGS from dpkg-buildflags (origin: vendor): -g -O2
    dpkg-buildpackage: export CPPFLAGS from dpkg-buildflags (origin: vendor): 
    dpkg-buildpackage: export CXXFLAGS from dpkg-buildflags (origin: vendor): -g -O2
    dpkg-buildpackage: export FFLAGS from dpkg-buildflags (origin: vendor): -g -O2
    dpkg-buildpackage: export LDFLAGS from dpkg-buildflags (origin: vendor): 
    dpkg-buildpackage: source package fglrx-installer
    dpkg-buildpackage: source version 8.95-1
    dpkg-buildpackage: source changed by AMD: Advanced Micro Devices. -http://ati.amd.com/support/driver.html-
     dpkg-source --before-build fglrx.g3XoDL
    dpkg-buildpackage: host architecture i386
     debian/rules build
    dh_testdir
    # move licenses away from binary dir
    if [ ! -d usr/share/doc/fglrx ]; then \
    	  mkdir -p usr/share/doc/fglrx; \
    	  mv usr/X11R6/bin/LICENSE.* usr/share/doc/fglrx; \
    	fi
    # set executable on user apps
    find usr/X11R6/bin -type f | xargs chmod a+x
    # remove exec bit from files that don't deserve it
    find usr/X11R6/include \
    	     usr/X11R6/lib \
    	     usr/X11R6/lib64 \
    	     usr/share usr/src     -type f | xargs chmod -x
    find: `usr/X11R6/include': No such file or directory
    find: `usr/X11R6/lib64': No such file or directory
    find lib -not -name "*.sh" -type f | xargs chmod -x
    find lib      -name "*.sh" -type f | xargs chmod +x
    # set proper permissions on /etc files
    if [ -d etc/ati ]; then			\
    		chmod 755 etc/ati ;			\
    		chmod 644 etc/ati/* ;		\
    		chmod a+x etc/ati/*.sh ;	\
    	fi
    if [ -f debian/fglrx.default ]; then \
    	  mv -v debian/fglrx.default debian/fglrx; \
    	fi
    `debian/fglrx.default' -> `debian/fglrx'
     fakeroot debian/rules binary
    dh_testdir
    # move licenses away from binary dir
    if [ ! -d usr/share/doc/fglrx ]; then \
    	  mkdir -p usr/share/doc/fglrx; \
    	  mv usr/X11R6/bin/LICENSE.* usr/share/doc/fglrx; \
    	fi
    # set executable on user apps
    find usr/X11R6/bin -type f | xargs chmod a+x
    # remove exec bit from files that don't deserve it
    find usr/X11R6/include \
    	     usr/X11R6/lib \
    	     usr/X11R6/lib64 \
    	     usr/share usr/src     -type f | xargs chmod -x
    find: `usr/X11R6/include': No such file or directory
    find: `usr/X11R6/lib64': No such file or directory
    find lib -not -name "*.sh" -type f | xargs chmod -x
    find lib      -name "*.sh" -type f | xargs chmod +x
    # set proper permissions on /etc files
    if [ -d etc/ati ]; then			\
    		chmod 755 etc/ati ;			\
    		chmod 644 etc/ati/* ;		\
    		chmod a+x etc/ati/*.sh ;	\
    	fi
    if [ -f debian/fglrx.default ]; then \
    	  mv -v debian/fglrx.default debian/fglrx; \
    	fi
    dh_testdir
    dh_testroot
    dh_clean -k
    dh_clean: dh_clean -k is deprecated; use dh_prep instead
    dh_clean: Compatibility levels before 5 are deprecated.
    dh_installdirs
    dh_installdirs: Compatibility levels before 5 are deprecated.
    # Create the directories to install into
    dh_installdirs -pfglrx-driver \
    		usr \
    		usr/lib/xorg \
    		usr/lib/xorg/modules \
    		usr/lib/dri \
    		usr/bin \
    		usr/sbin \
    		etc/acpi \
    		etc/acpi/events \
    		etc/default \
    		etc/X11/Xsession.d
    dh_installdirs: Compatibility levels before 5 are deprecated.
    dh_installdirs -pfglrx-driver-dev \
    		usr \
    		usr/include \
    		usr/lib
    dh_installdirs: Compatibility levels before 5 are deprecated.
    dh_installdirs -pfglrx-kernel-src \
    		usr/src/modules/fglrx \
    		usr/src/modules/fglrx/debian
    dh_installdirs: Compatibility levels before 5 are deprecated.
    dh_installdirs -A -pfglrx-amdcccle \
    		usr \
    		usr/bin \
    		usr/share \
    		usr/share/applnk \
    		usr/share/applications \
    		usr/share/icons \
    		usr/share/pixmaps
    dh_installdirs: Compatibility levels before 5 are deprecated.
    dh_installdirs -p \
    		usr/src
    dh_installdirs: Compatibility levels before 5 are deprecated.
    dh_install
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/X11R6/bin/fgl*"      "usr/bin"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/X11R6/bin/aticonfig" "usr/bin"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/sbin/atieventsd"     "usr/sbin"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_installman -pfglrx-driver "usr/share/man/man8/atieventsd.8"
    dh_installman: Compatibility levels before 5 are deprecated.
    # amd64 needs some library redirection
    dh_install -pfglrx-driver "usr/X11R6/lib/*.so*"           "usr/lib"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/X11R6/lib/modules/dri"     "usr/lib"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/X11R6/lib/modules/linux"   "usr/lib/xorg/modules"
    dh_install: Compatibility levels before 5 are deprecated.
    cp: cannot stat `./usr/X11R6/lib/modules/linux': No such file or directory
    dh_install: cp -a ./usr/X11R6/lib/modules/linux debian/fglrx-driver/usr/lib/xorg/modules/ returned exit code 1
    make: *** [binary] Error 2
    dpkg-buildpackage: error: fakeroot debian/rules binary gave error exit status 2
    Removing temporary directory: fglrx-install.ABmXYE
    jirkas@klapacius:~/build/catalyst12.2$ 
    
    Zkoušel jsem i starší verze Catalystů, stejný problém. Přijde mi to, že se používá nějaký špatný rules soubor. Také jsem zkoušel měnit verzi Debianu v --buildpkg, nejlépe to vypadá při použití Debian/lenny, pak zmizí errory s '/usr/X11R6/lib/modules/linux', ale stejně se to nesestaví...

    Nechci to spouštět jako root, ani obejít balíčkovací systém.

    Podobné dotazy jsem sice vygoogloval, ale řešení žádné.

    Použil bych sestavené balíčky z repozitářů, ale všude (non-free, backports) jsou jen hodně staré verze.

    Měl by, prosím, někdo nějaký tip?

    Odpovědi

    pushkin avatar 21.3.2012 08:16 pushkin | skóre: 43 | blog: FluxBlog
    Rozbalit Rozbalit vše Re: Nejdou sestavit Catalysty pro Squeeze
    Podle tohohle
    cp: cannot stat `./usr/X11R6/lib/modules/linux': No such file or directory
    bych si tipnul, že nemáš nainstalované hlavičkové soubory jádra a nebo vývojové balíčky X.Org. Nainstaluj si balíčky označené jako kernel-dev, xorg-dev a pár dalších (netuším přesně, jak se jmenují na Debianu, tak hledej :-)) atp. a zkus to znovu (seznam potřebných závislostí viz návod, strana 3).
    Jiří Svoboda avatar 21.3.2012 15:44 Jiří Svoboda | skóre: 37 | blog: cat /dev/mind | Prostějov
    Rozbalit Rozbalit vše Re: Nejdou sestavit Catalysty pro Squeeze
    kernel-headers jsem měl, xorg-dev jsem doinstaloval (v tom wiki ani v Release Notes nutnost xorg-dev balíčků přímo nezmiňují, ale mohlo mě to napadnout). Nicméně žádná změna. Ta cesta ./usr/X11R6/lib/modules/linux se určitě vztahuje na strom instalátoru, protože v Debianu se v současnosti nevyskytuje balíček, který by měl v cestě řetězec 'X11R6'.

    V tom stromu se to vyskytuje vícekrát. Relevantní jsou zřejmě cesty:

    arch/x86/usr/X11R6/lib/modules/

    xpic/usr/X11R6/lib/modules/

    V té druhé se adresář 'linux' vyskytuje, v té první ne. Teď vejrám do rozbaleného stromu toho instalátoru a nestačím se divit. A celé to procházet a příjít na to, kde je problém, to se mi teda moc nechce...
    pushkin avatar 22.3.2012 07:17 pushkin | skóre: 43 | blog: FluxBlog
    Rozbalit Rozbalit vše Re: Nejdou sestavit Catalysty pro Squeeze
    No jo, teď jsem si všimnul, že tam je problém mnohem dříve, než kam jsem koukal, divná je už řádka
    cp: cannot stat `/home/jirkas/build/catalyst12.2/fglrx-install.ABmXYE/x710/*': No such file or directory
    Podle téhle informace v Debianím fóru to vypadá na chybu instalátoru - asi selhává s parametrem --buildpkg, danému uživateli doporučují nainstalovat ovladače z Experimental. Víc bohužel neporadím - instalaci Debianu sice plánuji (včetně Catalystů), ale jestli se k tomu dostanu alespoň příští týden, čert ví...
    Jiří Svoboda avatar 22.3.2012 09:50 Jiří Svoboda | skóre: 37 | blog: cat /dev/mind | Prostějov
    Rozbalit Rozbalit vše Re: Nejdou sestavit Catalysty pro Squeeze
    Ovladače z experimental si nejsem jistý, jestli by fungovaly, vždyť ten modul musí být zkompilovaný proti úplně jinému jádru...

    Ale jinak x710 dobrý tip. Zkusil jsem installer rozbalit:

    ./amd-driver-installer-12-2-x86.x86_64.run --extract

    Uvnitř jsem pak udělal symlink x710->xpic a spustil:

    ./ati-installer.sh 12.2 --buildpkg Debian/stable

    A dostal jsem se trošku dál:
    jirkas@klapacius:~/build/catalyst12.2/fglrx-install.QXNgLQ$ ./ati-installer.sh 12.2 --buildpkg Debian/stable
    =====================================================================
     AMD Catalyst(TM) Proprietary Driver Installer/Packager 
    =====================================================================
    Generating package: Debian/stable
    Package build failed!
    Package build utility output:
    dpkg-buildpackage: export CFLAGS from dpkg-buildflags (origin: vendor): -g -O2
    dpkg-buildpackage: export CPPFLAGS from dpkg-buildflags (origin: vendor): 
    dpkg-buildpackage: export CXXFLAGS from dpkg-buildflags (origin: vendor): -g -O2
    dpkg-buildpackage: export FFLAGS from dpkg-buildflags (origin: vendor): -g -O2
    dpkg-buildpackage: export LDFLAGS from dpkg-buildflags (origin: vendor): 
    dpkg-buildpackage: source package fglrx-installer
    dpkg-buildpackage: source version 8.95-1
    dpkg-buildpackage: source changed by AMD: Advanced Micro Devices. -http://ati.amd.com/support/driver.html-
     dpkg-source --before-build fglrx.wb9sFl
    dpkg-buildpackage: host architecture i386
     debian/rules build
    dh_testdir
    # move licenses away from binary dir
    if [ ! -d usr/share/doc/fglrx ]; then \
    	  mkdir -p usr/share/doc/fglrx; \
    	  mv usr/X11R6/bin/LICENSE.* usr/share/doc/fglrx; \
    	fi
    # set executable on user apps
    find usr/X11R6/bin -type f | xargs chmod a+x
    # remove exec bit from files that don't deserve it
    find usr/X11R6/include \
    	     usr/X11R6/lib \
    	     usr/X11R6/lib64 \
    	     usr/share usr/src     -type f | xargs chmod -x
    find: `usr/X11R6/include': No such file or directory
    find: `usr/X11R6/lib64': No such file or directory
    find lib -not -name "*.sh" -type f | xargs chmod -x
    find lib      -name "*.sh" -type f | xargs chmod +x
    # set proper permissions on /etc files
    if [ -d etc/ati ]; then			\
    		chmod 755 etc/ati ;			\
    		chmod 644 etc/ati/* ;		\
    		chmod a+x etc/ati/*.sh ;	\
    	fi
    if [ -f debian/fglrx.default ]; then \
    	  mv -v debian/fglrx.default debian/fglrx; \
    	fi
    `debian/fglrx.default' -> `debian/fglrx'
     fakeroot debian/rules binary
    dh_testdir
    # move licenses away from binary dir
    if [ ! -d usr/share/doc/fglrx ]; then \
    	  mkdir -p usr/share/doc/fglrx; \
    	  mv usr/X11R6/bin/LICENSE.* usr/share/doc/fglrx; \
    	fi
    # set executable on user apps
    find usr/X11R6/bin -type f | xargs chmod a+x
    # remove exec bit from files that don't deserve it
    find usr/X11R6/include \
    	     usr/X11R6/lib \
    	     usr/X11R6/lib64 \
    	     usr/share usr/src     -type f | xargs chmod -x
    find: `usr/X11R6/include': No such file or directory
    find: `usr/X11R6/lib64': No such file or directory
    find lib -not -name "*.sh" -type f | xargs chmod -x
    find lib      -name "*.sh" -type f | xargs chmod +x
    # set proper permissions on /etc files
    if [ -d etc/ati ]; then			\
    		chmod 755 etc/ati ;			\
    		chmod 644 etc/ati/* ;		\
    		chmod a+x etc/ati/*.sh ;	\
    	fi
    if [ -f debian/fglrx.default ]; then \
    	  mv -v debian/fglrx.default debian/fglrx; \
    	fi
    dh_testdir
    dh_testroot
    dh_clean -k
    dh_clean: dh_clean -k is deprecated; use dh_prep instead
    dh_clean: Compatibility levels before 5 are deprecated.
    dh_installdirs
    dh_installdirs: Compatibility levels before 5 are deprecated.
    # Create the directories to install into
    dh_installdirs -pfglrx-driver \
    		usr \
    		usr/lib/xorg \
    		usr/lib/xorg/modules \
    		usr/lib/dri \
    		usr/bin \
    		usr/sbin \
    		etc/acpi \
    		etc/acpi/events \
    		etc/default \
    		etc/X11/Xsession.d
    dh_installdirs: Compatibility levels before 5 are deprecated.
    dh_installdirs -pfglrx-driver-dev \
    		usr \
    		usr/include \
    		usr/lib
    dh_installdirs: Compatibility levels before 5 are deprecated.
    dh_installdirs -pfglrx-kernel-src \
    		usr/src/modules/fglrx \
    		usr/src/modules/fglrx/debian
    dh_installdirs: Compatibility levels before 5 are deprecated.
    dh_installdirs -A -pfglrx-amdcccle \
    		usr \
    		usr/bin \
    		usr/share \
    		usr/share/applnk \
    		usr/share/applications \
    		usr/share/icons \
    		usr/share/pixmaps
    dh_installdirs: Compatibility levels before 5 are deprecated.
    dh_installdirs -p \
    		usr/src
    dh_installdirs: Compatibility levels before 5 are deprecated.
    dh_install
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/X11R6/bin/fgl*"      "usr/bin"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/X11R6/bin/aticonfig" "usr/bin"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/sbin/atieventsd"     "usr/sbin"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_installman -pfglrx-driver "usr/share/man/man8/atieventsd.8"
    dh_installman: Compatibility levels before 5 are deprecated.
    # amd64 needs some library redirection
    dh_install -pfglrx-driver "usr/X11R6/lib/*.so*"           "usr/lib"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/X11R6/lib/modules/dri"     "usr/lib"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/X11R6/lib/modules/linux"   "usr/lib/xorg/modules"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/X11R6/lib/modules/drivers" "usr/lib/xorg/modules"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/X11R6/lib/modules/extensions" "usr/lib/xorg/modules"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/X11R6/lib/modules/*.so"    "usr/lib/xorg/modules"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "usr/X11R6/lib/modules/*.a"     "usr/lib/xorg/modules"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "etc/fglrx*"                "etc"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "etc/ati"                   "etc"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "debian/70fglrx" 	       "etc/X11/Xsession.d"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "debian/fglrx-powermode.sh" "etc/acpi"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "debian/fglrx-*-aticonfig"  "etc/acpi/events"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver "debian/fglrx"              "etc/default"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_installinit -pfglrx-driver --name="atieventsd"
    dh_installinit: Compatibility levels before 5 are deprecated.
    # create symlinks to shared libs
    dh_link    -pfglrx-driver "usr/lib/libGL.so.1.2"		  "usr/lib/libGL.so.1"
    dh_link: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver-dev "usr/X11R6/lib/*.a"   "usr/lib"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver-dev "usr/X11R6/include/*" "usr/include"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-driver-dev "usr/include/*"       "usr/include"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-kernel-src \
    		lib/modules/fglrx/build_mod/*.c            \
    		lib/modules/fglrx/build_mod/*.h            \
    		lib/modules/fglrx/build_mod/*.sh           \
    		lib/modules/fglrx/build_mod/lib*           \
    		lib/modules/fglrx/build_mod/2.6.x/Makefile \
    		usr/src/modules/fglrx
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-kernel-src "debian/changelog" "usr/src/modules/fglrx/debian"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -pfglrx-kernel-src  \
    		debian/copyright        \
    		debian/compat           \
    		module/rules            \
    		module/control.template \
    		module/dirs.template    \
    		module/postinst         \
    		usr/src/modules/fglrx/debian
    dh_install: Compatibility levels before 5 are deprecated.
    (cd debian/fglrx-kernel-src/usr/src \
    	 && chown -R root:src modules \
    	 && tar -jcf fglrx.tar.bz2 modules \
    	 && rm -rf modules)
    # control panel package
    dh_install -A -pfglrx-amdcccle "usr/X11R6/bin/amdcccle"            		"usr/bin"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -A -pfglrx-amdcccle "usr/share/icons/*.xpm"             		"usr/share/icons"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -A -pfglrx-amdcccle "usr/share/icons/*.xpm"             		"usr/share/pixmaps"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -A -pfglrx-amdcccle "debian/amdcccle.desktop"				"usr/share/applications"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -A -pfglrx-amdcccle "debian/amdcccle.kdelnk"					"usr/share/applnk"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_install -A -pfglrx-amdcccle "usr/share/ati"							"usr/share"
    dh_install: Compatibility levels before 5 are deprecated.
    dh_desktop    -pfglrx-amdcccle
    dh_desktop: This program is deprecated, and does nothing anymore.
    dh_desktop: Compatibility levels before 5 are deprecated.
    dh_installdocs
    dh_installdocs: Compatibility levels before 5 are deprecated.
    dh_installdocs -pfglrx-driver usr/share/doc/fglrx/*
    dh_installdocs: Compatibility levels before 5 are deprecated.
    #dh_installchangelogs
    dh_link
    dh_link: Compatibility levels before 5 are deprecated.
    dh_strip
    dh_strip: Compatibility levels before 5 are deprecated.
    dh_compress
    dh_compress: Compatibility levels before 5 are deprecated.
    dh_makeshlibs
    dh_makeshlibs: Compatibility levels before 5 are deprecated.
    dh_installdeb
    dh_installdeb: Compatibility levels before 5 are deprecated.
    LD_PRELOAD= dh_shlibdeps --exclude=emul
    dh_shlibdeps: Compatibility levels before 5 are deprecated.
    dpkg-shlibdeps: error: couldn't find library libatiuki.so.1 needed by debian/fglrx-driver/usr/lib/xorg/modules/linux/libfglrxdrm.so (ELF format: 'elf32-i386'; RPATH: '').
    Note: libraries are not searched in other binary packages that do not have any shlibs or symbols file.
    To help dpkg-shlibdeps find private libraries, you might need to set LD_LIBRARY_PATH.
    dh_shlibdeps: dpkg-shlibdeps -Tdebian/fglrx-driver.substvars debian/fglrx-driver/usr/lib/libAMDXvBA.so.1.0 debian/fglrx-driver/usr/lib/libXvBAW.so.1.0 debian/fglrx-driver/usr/lib/libatiadlxx.so debian/fglrx-driver/usr/lib/dri/fglrx_dri.so debian/fglrx-driver/usr/lib/libfglrx_dm.so.1.0 debian/fglrx-driver/usr/lib/xorg/modules/amdxmm.so debian/fglrx-driver/usr/lib/xorg/modules/linux/libfglrxdrm.so debian/fglrx-driver/usr/lib/xorg/modules/extensions/fglrx/fglrx-libglx.so debian/fglrx-driver/usr/lib/xorg/modules/glesx.so debian/fglrx-driver/usr/lib/xorg/modules/drivers/fglrx_drv.so debian/fglrx-driver/usr/bin/fglrxinfo debian/fglrx-driver/usr/bin/aticonfig debian/fglrx-driver/usr/bin/fgl_glxgears debian/fglrx-driver/usr/sbin/atieventsd returned exit code 2
    make: *** [binary] Error 9
    dpkg-buildpackage: error: fakeroot debian/rules binary gave error exit status 2
    jirkas@klapacius:~/build/catalyst12.2/fglrx-install.QXNgLQ$ 
    
    Zdá se, že mu chybí 'libatiuki.so.1'. Ta knihovna je v './arch/x86/usr/lib/', ale nenajde ji ani po manuálním nastaveni LD_LIBRARY_PATH (pro jistotu jsem zadal absolutní cestu)...
    Jiří Svoboda avatar 22.3.2012 10:25 Jiří Svoboda | skóre: 37 | blog: cat /dev/mind | Prostějov
    Rozbalit Rozbalit vše Re: Nejdou sestavit Catalysty pro Squeeze
    Tak pomohl LD_LIBRARY_PATH a současně doplnění symlinku libatiuki.so.1->libatiuki.so.1.0, ale stejně ještě nejsem doma:
    ...
    LD_PRELOAD= dh_shlibdeps --exclude=emul
    dh_shlibdeps: Compatibility levels before 5 are deprecated.
    dpkg-shlibdeps: error: no dependency information found for /home/jirkas/build/catalyst12.2/fglrx-install.QXNgLQ/arch/x86/usr/lib/libatiuki.so.1 (used by debian/fglrx-driver/usr/lib/xorg/modules/linux/libfglrxdrm.so).
    dh_shlibdeps: dpkg-shlibdeps -Tdebian/fglrx-driver.substvars debian/fglrx-driver/usr/lib/libAMDXvBA.so.1.0 debian/fglrx-driver/usr/lib/libXvBAW.so.1.0 debian/fglrx-driver/usr/lib/libatiadlxx.so debian/fglrx-driver/usr/lib/dri/fglrx_dri.so debian/fglrx-driver/usr/lib/libfglrx_dm.so.1.0 debian/fglrx-driver/usr/lib/xorg/modules/amdxmm.so debian/fglrx-driver/usr/lib/xorg/modules/linux/libfglrxdrm.so debian/fglrx-driver/usr/lib/xorg/modules/extensions/fglrx/fglrx-libglx.so debian/fglrx-driver/usr/lib/xorg/modules/glesx.so debian/fglrx-driver/usr/lib/xorg/modules/drivers/fglrx_drv.so debian/fglrx-driver/usr/bin/fglrxinfo debian/fglrx-driver/usr/bin/aticonfig debian/fglrx-driver/usr/bin/fgl_glxgears debian/fglrx-driver/usr/sbin/atieventsd returned exit code 2
    make: *** [binary] Error 9
    dpkg-buildpackage: error: fakeroot debian/rules binary gave error exit status 2
    jirkas@klapacius:~/build/catalyst12.2/fglrx-install.QXNgLQ$ 
    
    Ale teď už teda fakt nevím. Podle té hlášky je to asi fakt zmršená ta Debianí část.

    Ha, ještě jsem teď zkusil '--buildpkg Slackware/Slackware' a kernel modul se zkompiloval. Vytvoření balíčků ale logicky selhalo. Nicméně se zdá, že všechny soubory k zabalení jsou v './packages/Slackware/_working_directory_/'. Dělám to na jiném stroji, tak to teď nemůžu vyzkoušet, ale určitě dám ještě vědět.
    Jiří Svoboda avatar 23.3.2012 12:08 Jiří Svoboda | skóre: 37 | blog: cat /dev/mind | Prostějov
    Rozbalit Rozbalit vše Re: Nejdou sestavit Catalysty pro Squeeze
    Takže...

    Debianí balíčky nejdou sestavit, protože je to v AMD instalátoru nějak nadrbáno, zřejmě jsou tam staré scripty. Vypadá to, že Ubuntu má stejný problém.

    Balíčky 'xorg-dev' a spol. nejsou k sestavení potřeba, kompiluje se pouze kernel modul, takže stačí kernel-headers.

    Sestavení jsem nakonec obešel tímto postupem:

    1) Rozbalit instalátor:

    ./amd-driver-installer-12-2-x86.x86_64.run --extract

    2) Uvniř rozbaleného adresáře spustit:

    fakeroot ./ati-installer.sh 12.2 --buildpkg Slackware/Slackware

    Tenhle příkaz jako první úspešně zkompiluje kernel modul a připraví do adresářové struktury soubory potřebné k sestavení Slackware balíčku. Na samotném vytvoření balíčku pak samozřejmě selže.

    3) Soubory jsou v adresáři instalátoru 'packages/Slackware/_working_directory_/' a ty potřebné :-) stačí nakopírovat na správná místa adresářové struktury Debianu.

    (Kernel modul jsem rozgzipoval a spustil 'depmod -a' - nevím, zda bylo nutné. Dvě knihovny, které se přepisovaly, jsem zálohoval.)

    4) Jako root spustit:

    aticonfig --initial -f

    což vyrobí výchozí 'xorg.conf'.

    Výsledek:

    Mám systém, kde jsem sice obešel balíčkovací systém, ale neprováděl jsem build jako root, takže vím, co kde mám. Musím ale počítat s tím, že při updatu OpenGL knihoven se to rozesere. X.org používají správný ovladač a akcelerují všechno... kromě 3D... :-( X.org moduly glx, dri, dri2, fglrx, fglrxdrm jsou podle logu úspěšně tam a pak najednou:
    ...
    ukiDynamicMajor: found major device number 251
    ukiDynamicMajor: found major device number 251
    ukiOpenByBusid: Searching for BusID PCI:0:1:0
    ukiOpenDevice: node name is /dev/ati/card0
    ukiOpenDevice: open result is 14, (OK)
    ukiOpenByBusid: ukiOpenMinor returns 14
    ukiOpenByBusid: ukiGetBusid reports PCI:0:1:0
    (EE) AIGLX error: failed to load OpenGL driver
    (EE) AIGLX: reverting to software rendering
    ...
    
    V CLI to vidím jako:
    jirkas@tlamsa:~$ fglrxinfo 
    X Error of failed request:  BadRequest (invalid request code or no such operation)
      Major opcode of failed request:  137 (GLX)
      Minor opcode of failed request:  19 (X_GLXQueryServerString)
      Serial number of failed request:  16
      Current serial number in output stream:  16
    jirkas@tlamsa:~$
    
    A s tím už si teda fakt nevím rady. Štěstí, že 3D nepotřebuju, je to HTPC...

    23.3.2012 13:17 ewew | skóre: 40 | blog: ewewov_blog
    Rozbalit Rozbalit vše Re: Nejdou sestavit Catalysty pro Squeeze
    Skúšal si aj tento návod čo je priamo na domovskej stránke debianinu.
    Root v linuxe : "Root povedal, linux vykona."

    Založit nové vlákno • Nahoru

    Tiskni Sdílej: Linkuj Jaggni to Vybrali.sme.sk Google Del.icio.us Facebook

    ISSN 1214-1267   www.czech-server.cz
    © 1999-2015 Nitemedia s. r. o. Všechna práva vyhrazena.